@@ -12,8 +12,6 @@ read VERSION
 echo
 echo "--- Setup ---"
 set -x
-pip install --upgrade readme-renderer
-pip install --upgrade twine
 rm -rf build dist *.egg-info
 git pull || true
 set +x
